# -*- coding: utf-8 -*-
import os
from sqlalchemy import create_engine, \
    Column, Integer, String, ForeignKey
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker, relationship

db_path = os.path.join(os.path.dirname(__file__), 'phone.db')
engine = create_engine('sqlite:///' + db_path)
Session = sessionmaker(bind=engine)
Base = declarative_base()


class Region(Base):
    """归属地"""
    __tablename__ = 'regions'
    id = Column(Integer, primary_key=True)
    province = Column(String)
    city = Column(String)
    zip_code = Column(String)
    area_code = Column(String)
    phones = relationship('Phone', lazy='dynamic', backref='region')

    def content(self):
        return {
            'province': self.province,
            'city': self.city,
            'zip_code': self.zip_code,
            'area_code': self.area_code,
        }


class Phone(Base):
    """手机号段"""
    __tablename__ = 'phones'
    id = Column(Integer, primary_key=True)
    number = Column(Integer, index=True)
    type = Column(Integer)
    region_id = Column(Integer, ForeignKey('regions.id'))

    @staticmethod
    def get_phone_no_type(no):
        if no == 4:
            return '电信虚拟运营商'
        if no == 5:
            return '联通虚拟运营商'
        if no == 6:
            return '移动虚拟运营商'
        if no == 3:
            return '电信'
        if no == 2:
            return '联通'
        if no == 1:
            return '移动'

    def detail(self):
        return (
            self.number,
            self.get_phone_no_type(self.type),
            self.region.content()
        )


Base.metadata.create_all(engine)



# -*- coding: utf-8 -*-
import unittest
from sqlalchemy.orm.dynamic import AppenderQuery
from model import Session, Phone, Region


class TestModel(unittest.TestCase):

    def setUp(self):
        self.session = Session()

    def tearDown(self):
        pass

    def test_phone(self):
        p = self.session.query(Phone).filter_by(number=1761166).first()
        self.assertEqual(p.number, 1761166)
        self.assertEqual(p.type, 2)
        self.assertIsInstance(p.region, Region)

    def test_region(self):
        r = self.session.query(Region).filter_by(zip_code='100000').first()
        self.assertEqual(r.zip_code, '100000')
        self.assertEqual(r.area_code, '010')
        self.assertEqual(r.city, '北京')
        self.assertEqual(r.province, '北京')
        self.assertIsInstance(r.phones, AppenderQuery)


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

with open('README.md') as f:
    README = f.read()

NAME = 'phone-db'
DESCRIPTION = '手机号码SQLite数据库'
AUTHOR = 'lalala223'
AUTHOR_EMAIL = 'hi@lalala.ink'
URL = 'https://github.com/lalala223/phone-db'
VERSION = '1.0.3'

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=README,
    long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    license='MIT',
    url=URL,
    include_package_data=True,
    install_requires=['sqlalchemy'],
    packages=find_packages(),
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
    ],
    zip_safe=False,
)
